## Galen
The name of the project comes from  League of Legends.
Now galen is a common tool library 
## Installation

```shell
pip install garen
```
## Examples


## Changelogs

| version      | release notes |
| :---      | :---    |
| 0.1.2    | add markdown |
| 0.1.1    | project init cookie split function |
